/**
 * @license
 * Copyright 2019 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */

 import {LitElement, html, CSSResultGroup} from 'lit';
 import {customElement, property} from 'lit/decorators.js';
import { globalStyles } from '../styles';
 
 /**
  * @fires count-changed - Indicates when the count changes
  * @slot - This element has a slot
  * @csspart button - The button
  */
 @customElement('dev-console-product-details')
 export class DevConsoleProductDetails extends LitElement {
    static override styles?: CSSResultGroup | undefined = [globalStyles];
     @property({ attribute: '.productDetails' })
     productDetails:any = {}

     override render(){
         return html`
            <div class="grid grid-cols-7 gap-20">
                <div class="col-span-5 flex flex-col space-y-6">
                    <div class="flex flex-col space-y-2">
                        <strong>Learn about the Products</strong>
                        <p>${this.productDetails.description}</p>
                        <a>${`Find out more about ${this.productDetails.name}`}</a>
                    </div>
                    <div class="flex flex-col space-y-2">
                        <strong>Technical Documentation</strong>
                        <div class="flex flex-col space-y-4">
                            ${this.productDetails.documentations.map((doc:any)=>
                                html`
                                    <div class="flex flex-col space-y-1">
                                        <a href=${doc.url}>${doc.name}</a>
                                        <p>${doc.description}</p>
                                    </div>
                                `    
                            )}
                        </div>
                    </div>
                </div>
                <div class="col-span-2 flex flex-col space-y-2">
                    <strong>Utilities</strong>
                    <div class="flex flex-col space-y-4">
                        ${this.productDetails.utilities.map((doc:any)=>
                            html`
                                <a href=${doc.url}>${doc.name}</a>
                            `    
                        )}
                    </div>
                </div>
            </div>
         `
     }
 }

 declare global {
    interface HTMLElementTagNameMap {
      'dev-console-product-details': DevConsoleProductDetails;
    }
  }